# -*- coding: utf-8 -*-

# @File  : news.py
# @Author: Lomo
# @Site  : lomo.space
# @Date  : 2021-11-20
# @Desc  : crawler new demo
# URL : https://www.kancloud.cn/lizhixuan/free_api

import requests


class ChinaNews(object):
    def __init__(self):
        self.net_ease_url = 'https://api.apiopen.top/getWangYiNews'

    def get_net_news(self, page, count):
        req = requests.post(self.net_ease_url, {
            "page": page,
            "count": count
        })
        if req.status_code == 200:
            # print(req.json())
            rep = req.json()
            print(rep)
            return rep.get('result')


if __name__ == '__main__':
    r = ChinaNews().get_net_news(page=1, count=10)
    print(len(r))



# -*- coding: utf-8 -*-

# @File  : main.py
# @Author: Lomo
# @Site  : lomo.space
# @Date  : 2021-11-20
# @Desc  : main

import itertools


class CartesianProduct(object):
    def __init__(self, case_list, value_list):
        self.items = case_list
        self.values = value_list

    def generate_cases(self):
        if self.items and self.values:
            n = 0
            for i in itertools.product(self.items, self.values):
                print(' 输入 '.join(i))
                n += 1
            print("共生成 {0} 组结果".format(n))
        else:
            return None


# single function
def get_sum(m, n):
    if isinstance(m, int) and isinstance(n, int):
        return m + n
    else:
        print("m: {0}, n: {1} is not int number...".format(m, n))
        return None


if __name__ == '__main__':
    # items = ['用户名', '密码']
    items = ['我', '你', '他', '她', '它']
    # values = ['正确', '不正确', '特殊符号', '超过最大长度']
    values = ['1', '2', '5', '11', '100']
    cd = CartesianProduct(items, values)
    cd.generate_cases()



# -*- coding: utf-8 -*-

# @File  : setup.py
# @Author: Lomo
# @Site  : lomo.space
# @Date  : 2021-11-20
# @Desc  : refer: https://github.com/navdeep-G/setup.py/blob/master/setup.py
# usage: (py_package)  lomo@Lomo  ~/Documents/codes/py_package/pkg_lomo  python3 setup.py upload

import io
import os
import sys
from shutil import rmtree

from distutils.core import setup
from setuptools import find_packages, Command


# 需要安装的依赖包
REQUIRED = [
    "requests~=2.26.0",
]

EXTRAS = {
}

NAME = 'pkg-lomo'
DESCRIPTION = 'pkg lib form lomo.space'
URL = 'https://lomo.space'
EMAIL = 'lomo@lomo.space'
AUTHOR = 'lomo.space'
KEY_WORDS = "pkg lomo lib"
VERSION = '0.1.1.1'
REQUIRES_PYTHON = '>3.6.0'

here = os.path.abspath(os.path.dirname(__file__))
try:
    with io.open(os.path.join(here, 'README.rst'), 'r') as f:
        long_description = '\n' + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION


class UploadCommand(Command):
    """
    setup.py upload.
    """
    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        self.status('Uploading the package to PyPI via Twine…')
        os.system('twine upload dist/*')

        sys.exit()


# 测试依赖包
TESTS = [

]

setup(
    name=NAME,  # 打包后的包文件名
    version=VERSION,  # 版本号
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    tests_require=TESTS,
    include_package_data=True,
    packages=find_packages(),  # 可以添加 exclude=["tests", "*.tests", "*.tests.*", "tests.*"] 排除不需要的包目录
    platforms=["all"],
    python_requires=REQUIRES_PYTHON,
    author=AUTHOR,
    author_email=EMAIL,
    maintainer=AUTHOR,
    maintainer_email=EMAIL,
    url=URL,
    license='MIT',
    keywords=KEY_WORDS,
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: Chinese (Simplified)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries'
    ],
    # 上传脚本化
    cmdclass={
        'upload': UploadCommand
    },
)

print("\nWelcome use pkg-lomo Library")



# -*- coding: utf-8 -*-

# @File  : crawler.py
# @Author: Lomo
# @Site  : lomo.space
# @Date  : 2021-11-20
# @Desc  : crawler demo
# URL : https://www.kancloud.cn/lizhixuan/free_api

import requests


class Crawler(object):
    def __init__(self):
        pass

    @staticmethod
    def is_ok(url):
        req = requests.get(url)
        print(req.status_code)
        if req.status_code == 200:
            return True
        else:
            return False

    @staticmethod
    def get_contents(url):
        req = requests.api.get(url)
        print(req.content)
        # print(req.json())

    @staticmethod
    def get_jokes(url=None, **params):
        url = url if url else 'https://api.apiopen.top/getJoke'
        page = params.get('page')
        count = params.get('count')
        _type = params.get('type')
        req_params = {'page': page, 'count': count, 'type': _type}
        req = requests.get(url, req_params)
        print(req.status_code)
        if len(req.json()['result']):
            print(len(req.json()['result']))
            return req.json()['result']
        else:
            return None

    @staticmethod
    def search_joke_by_sid(sid, url=None):
        # url = url if url else 'https://api.apiopen.top/getSingleJoke'
        # url = url + '?sid=' + sid
        if not url:
            url = 'https://api.apiopen.top/getSingleJoke'
        req = requests.get(url=url, params={'sid': sid})
        print(req.url)
        print(req.status_code)
        # print(req.json())
        return req.json()['result']


if __name__ == '__main__':
    # Crawler.get_contents(url='https://www.baidu.com/')
    # Crawler.is_ok('https://www.baidu.com/')
    print(Crawler.search_joke_by_sid(sid='31551566'))

    # params = {'page': 1, 'count': 5, 'type': 'all'}
    # print(Crawler.get_jokes(**params))
